@@ -32,12 +32,16 @@
 
 /**
  * \file
- * Pink's compatibility macros
+ * \brief Pink's compatibility macros
+ *
+ * \ingroup g_compat
  **/
 
 /**
  * Define for the availability of pink_bitness_wordsize() function.
  *
+ * \ingroup g_compat
+ *
  * \see pink_bitness_wordsize
  *
  * \since 0.0.3
@@ -47,6 +51,8 @@
 /**
  * Define for the availability of pink_decode_string_array_member() function.
  *
+ * \ingroup g_compat
+ *
  * \see pink_decode_string_array_member
  *
  * \since 0.0.3
@@ -56,6 +62,8 @@
 /**
  * Define for the availability of pink_decode_string_array_member_persistent() function.
  *
+ * \ingroup g_compat
+ *
  * \see pink_decode_string_array_member_persistent
  *
  * \since 0.0.3
@@ -65,6 +73,8 @@
 /**
  * Define for the availability of pink_trace_sysemu() function.
  *
+ * \ingroup g_compat
+ *
  * \see pink_trace_sysemu()
  *
  * \since 0.0.5
@@ -74,6 +84,8 @@
 /**
  * Define for the availability of pink_trace_sysemu_singlestep() function.
  *
+ * \ingroup g_compat
+ *
  * \see pink_trace_sysemu_singlestep()
  *
  * \since 0.0.5
@@ -83,6 +95,8 @@
 /**
  * Define for the availability of nl member (netlink) of #pink_socket_address_t
  *
+ * \ingroup g_compat
+ *
  * \see pink_socket_address_t
  *
  * \since 0.0.5
@@ -92,6 +106,8 @@
 /**
  * Define for the availability of length member of #pink_socket_address_t
  *
+ * \ingroup g_compat
+ *
  * \see pink_socket_address_t
  *
  * \since 0.0.5
@@ -101,10 +117,39 @@
 /**
  * Define for the availability of pink_util_set_arg() function.
  *
+ * \ingroup g_compat
+ *
  * \see pink_util_set_arg()
  *
  * \since 0.0.5
  **/
 #define PINK_UTIL_SET_ARG_AVAILABLE 1
 
+/**
+ * Define for the availability of #PINK_EVENT_TRAP constant.
+ *
+ * \see pink_event_decide()
+ *
+ * \since 0.0.6
+ **/
+#define PINK_EVENT_TRAP_AVAILABLE 1
+
+/**
+ * Define for the availability of pink_trace_lwpinfo() function.
+ *
+ * \see pink_trace_lwpinfo()
+ *
+ * \since 0.0.6
+ **/
+#define PINK_TRACE_LWPINFO_AVAILABLE 1
+
+/**
+ * Define for the availability of pink_trace_followfork() function.
+ *
+ * \see pink_trace_followfork()
+ *
+ * \since 0.0.6
+ **/
+#define PINK_TRACE_FOLLOWFORK_AVAILABLE 1
+
 #endif /* PINKTRACE_GUARD_COMPAT_H */
