@@ -1,7 +1,7 @@
 /* vim: set cino= fo=croql sw=8 ts=8 sts=0 noet cin fdm=syntax : */
 
 /*
- * Copyright (c) 2010 Ali Polatel <alip@exherbo.org>
+ * Copyright (c) 2010, 2011 Ali Polatel <alip@exherbo.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -32,7 +32,9 @@
 
 /**
  * \file
- * Pink's system call decoders
+ * \brief Pink's system call decoders
+ *
+ * \ingroup g_decode
  **/
 
 #include <stdbool.h>
@@ -49,20 +51,23 @@ extern "C" {
 /**
  * Get the data in argument arg and place it in dest.
  *
+ * \ingroup g_decode
+ *
  * \param pid Process ID of the child whose argument is to be received.
  * \param bitness Bitness of the child
  * \param ind The index of the argument (0-5, see #PINK_MAX_INDEX)
  * \param dest Pointer to store the data
  * \param len Length of the data
  **/
-PINK_NONNULL(4)
 bool
-pink_decode_simple(pid_t pid, pink_bitness_t bitness, unsigned ind, void *dest, size_t len);
+pink_decode_simple(pid_t pid, pink_bitness_t bitness, unsigned ind, void *dest, size_t len) PINK_GCC_ATTR((nonnull(4)));
 
 /**
  * Get the string argument and place it in dest.
  *
- * \note On FreeBSD this function is equivalent to pink_decode_simple().
+ * \ingroup g_decode
+ *
+ * \attention On FreeBSD this function is equivalent to pink_decode_simple().
  *
  * \param pid Process ID of the child whose argument is to be received.
  * \param bitness Bitness of the child
@@ -72,22 +77,25 @@ pink_decode_simple(pid_t pid, pink_bitness_t bitness, unsigned ind, void *dest,
  *
  * \return true on success, false on failure and sets errno accordingly.
  **/
-PINK_NONNULL(4)
 bool
-pink_decode_string(pid_t pid, pink_bitness_t bitness, unsigned ind, char *dest, size_t len);
+pink_decode_string(pid_t pid, pink_bitness_t bitness, unsigned ind, char *dest, size_t len) PINK_GCC_ATTR((nonnull(4)));
 
 /**
  * Like pink_decode_string() but allocates the string itself.
  *
+ * \ingroup g_decode
+ *
  * \return The path on success, NULL on failure and sets errno
  * accordingly.
  **/
 char *
-pink_decode_string_persistent(pid_t pid, pink_bitness_t bitness, unsigned ind);
+pink_decode_string_persistent(pid_t pid, pink_bitness_t bitness, unsigned ind) PINK_GCC_ATTR((malloc));
 
 /**
  * Decode the requested member of a NULL-terminated string array.
  *
+ * \ingroup g_decode
+ *
  * \param pid Process ID of the child
  * \param bitness Bitness of the child
  * \param arg The address of the argument, see pink_util_get_arg()
@@ -101,13 +109,18 @@ pink_decode_string_persistent(pid_t pid, pink_bitness_t bitness, unsigned ind);
  *
  * \since 0.0.3
  **/
-PINK_NONNULL(5)
 bool
-pink_decode_string_array_member(pid_t pid, pink_bitness_t bitness, long arg, unsigned ind, char *dest, size_t len, bool *nil);
+pink_decode_string_array_member(pid_t pid, pink_bitness_t bitness, long arg, unsigned ind, char *dest, size_t len, bool *nil) PINK_GCC_ATTR((nonnull(5)));
 
 /**
  * Like pink_decode_string_array_member() but allocates the string itself.
  *
+ * \ingroup g_decode
+ *
+ * \attention If the array member is NULL, this function returns NULL but doesn't
+ * modify errno. Check errno after the call to distinguish between success and
+ * failure for a NULL return.
+ *
  * \param pid Process ID of the child
  * \param bitness Bitness of the child
  * \param arg The address of the argument, see pink_util_get_arg()
@@ -115,19 +128,17 @@ pink_decode_string_array_member(pid_t pid, pink_bitness_t bitness, long arg, uns
  *
  * \return The string on success, NULL on failure and sets errno accordingly.
  *
- * \note If the array member is NULL, this function returns NULL but doesn't
- * modify errno. Check errno after the call to distinguish between success and
- * failure for a NULL return.
- *
  * \since 0.0.3
  **/
 char *
-pink_decode_string_array_member_persistent(pid_t pid, pink_bitness_t bitness, long arg, unsigned ind);
+pink_decode_string_array_member_persistent(pid_t pid, pink_bitness_t bitness, long arg, unsigned ind) PINK_GCC_ATTR((malloc));
 
 #if defined(PINKTRACE_LINUX) || defined(DOXYGEN)
 /**
  * Decode the socket call and place it in call.
  *
+ * \ingroup g_decode
+ *
  * \note Availability: Linux
  * \note This function decodes the socketcall(2) system call on some
  * architectures. On others it's equivalent to pink_util_get_syscall().
@@ -140,13 +151,14 @@ pink_decode_string_array_member_persistent(pid_t pid, pink_bitness_t bitness, lo
  *
  * \return true on success, false on failure and sets errno accordingly.
  **/
-PINK_NONNULL(3)
 bool
-pink_decode_socket_call(pid_t pid, pink_bitness_t bitness, long *subcall);
+pink_decode_socket_call(pid_t pid, pink_bitness_t bitness, long *subcall) PINK_GCC_ATTR((nonnull(3)));
 
 /**
  * Get the socket file descriptor in argument arg and place it in fd.
  *
+ * \ingroup g_decode
+ *
  * \note Availability: Linux
  * \note This function decodes the socketcall(2) system call on some
  * architectures.
@@ -158,13 +170,14 @@ pink_decode_socket_call(pid_t pid, pink_bitness_t bitness, long *subcall);
  *
  * \return true on success, false on failure and sets errno accordingly.
  **/
-PINK_NONNULL(4)
 bool
-pink_decode_socket_fd(pid_t pid, pink_bitness_t bitness, unsigned ind, long *fd);
+pink_decode_socket_fd(pid_t pid, pink_bitness_t bitness, unsigned ind, long *fd) PINK_GCC_ATTR((nonnull(4)));
 #endif /* defined(PINKTRACE_LINUX)... */
 
 /**
- * Get the socket address and place it in addr_r.
+ * Get the socket address and place it in paddr.
+ *
+ * \ingroup g_decode
  *
  * \note This function decodes the socketcall(2) system call on some
  * architectures.
@@ -184,9 +197,8 @@ pink_decode_socket_fd(pid_t pid, pink_bitness_t bitness, unsigned ind, long *fd)
  *
  * \return true on success, false on failure and sets errno accordingly.
  **/
-PINK_NONNULL(5)
 bool
-pink_decode_socket_address(pid_t pid, pink_bitness_t bitness, unsigned ind, long *fd, pink_socket_address_t *paddr);
+pink_decode_socket_address(pid_t pid, pink_bitness_t bitness, unsigned ind, long *fd, pink_socket_address_t *paddr) PINK_GCC_ATTR((nonnull(5)));
 
 #ifdef __cplusplus
 }
