@@ -1,7 +1,7 @@
 /* vim: set cino= fo=croql sw=8 ts=8 sts=0 noet cin fdm=syntax : */
 
 /*
- * Copyright (c) 2010 Ali Polatel <alip@exherbo.org>
+ * Copyright (c) 2010, 2011 Ali Polatel <alip@exherbo.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -32,7 +32,9 @@
 
 /**
  * \file
- * Pink's socket related data structures and functions
+ * \brief Pink's socket related data structures and functions
+ *
+ * \ingroup g_socket
  **/
 
 #if defined(PINKTRACE_FREEBSD) || defined(DOXYGEN)
@@ -49,7 +51,9 @@
 #include <pinktrace/gcc.h>
 
 /**
- * This struct defines a decoded socket address.
+ * \brief Structure which defines a decoded socket address.
+ *
+ * \ingroup g_socket
  **/
 typedef struct {
 	/** Family of the socket address **/
@@ -105,6 +109,8 @@ typedef struct {
 /**
  * Decoded socket subcalls
  *
+ * \ingroup g_socket
+ *
  * \note Availability: Linux
  **/
 typedef enum {
@@ -156,6 +162,8 @@ extern "C" {
  * bind etc. - are implemented as separate system calls. On others these calls
  * are subcalls of the socketcall() system call.
  *
+ * \ingroup g_socket
+ *
  * \note Availability: Linux
  *
  * \see pink_socket_subcall_t
@@ -163,22 +171,22 @@ extern "C" {
  * \param bitness Bitness of the child
  * \return true if socketcall() system call is available, false otherwise.
  **/
-PINK_PURE
 bool
-pink_has_socketcall(pink_bitness_t bitness);
+pink_has_socketcall(pink_bitness_t bitness) PINK_GCC_ATTR((pure));
 
 /**
  * Name the given socket subcall
  *
+ * \ingroup g_socket
+ *
  * \note Availability: Linux
  *
  * \param subcall The socket subcall
  *
  * \return The name of the subcall
  **/
-PINK_PURE
 const char *
-pink_name_socket_subcall(pink_socket_subcall_t subcall);
+pink_name_socket_subcall(pink_socket_subcall_t subcall) PINK_GCC_ATTR((pure));
 
 #ifdef __cplusplus
 }
