@@ -1,7 +1,7 @@
 /* vim: set cino= fo=croql sw=8 ts=8 sts=0 noet cin fdm=syntax : */
 
 /*
- * Copyright (c) 2010 Ali Polatel <alip@exherbo.org>
+ * Copyright (c) 2010, 2011 Ali Polatel <alip@exherbo.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -295,7 +295,7 @@ check_index(unsigned ind)
  * only by the parent.
  */
 static VALUE
-pinkrb_trace_me(PINK_UNUSED VALUE mod)
+pinkrb_trace_me(PINK_GCC_ATTR((unused)) VALUE mod)
 {
 	if (!pink_trace_me())
 		rb_sys_fail("pink_trace_me()");
@@ -320,7 +320,7 @@ pinkrb_trace_me(PINK_UNUSED VALUE mod)
  * On Linux, this argument is not used.
  */
 static VALUE
-pinkrb_trace_cont(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
+pinkrb_trace_cont(int argc, VALUE *argv, PINK_GCC_ATTR((unused)) VALUE mod)
 {
 	pid_t pid;
 	long sig, addr;
@@ -363,7 +363,7 @@ pinkrb_trace_cont(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
  * is delivered or not.
  */
 static VALUE
-pinkrb_trace_resume(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
+pinkrb_trace_resume(int argc, VALUE *argv, PINK_GCC_ATTR((unused)) VALUE mod)
 {
 	pid_t pid;
 	long sig;
@@ -394,7 +394,7 @@ pinkrb_trace_resume(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
  * Kills the traced child process with SIGKILL.
  */
 static VALUE
-pinkrb_trace_kill(PINK_UNUSED VALUE mod, VALUE vpid)
+pinkrb_trace_kill(PINK_GCC_ATTR((unused)) VALUE mod, VALUE vpid)
 {
 	pid_t pid;
 
@@ -416,7 +416,7 @@ pinkrb_trace_kill(PINK_UNUSED VALUE mod, VALUE vpid)
  * PinkTrace::Trace.cont.
  */
 static VALUE
-pinkrb_trace_singlestep(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
+pinkrb_trace_singlestep(int argc, VALUE *argv, PINK_GCC_ATTR((unused)) VALUE mod)
 {
 	pid_t pid;
 	long sig;
@@ -451,7 +451,7 @@ pinkrb_trace_singlestep(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
  * PinkTrace::Trace.cont.
  */
 static VALUE
-pinkrb_trace_syscall(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
+pinkrb_trace_syscall(int argc, VALUE *argv, PINK_GCC_ATTR((unused)) VALUE mod)
 {
 	pid_t pid;
 	long sig;
@@ -488,16 +488,16 @@ pinkrb_trace_syscall(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
  * Availability: FreeBSD
  */
 #if !defined(PINKTRACE_FREEBSD)
-PINK_NORETURN
+PINK_GCC_ATTR((noreturn))
 #endif
 static VALUE
 pinkrb_trace_syscall_entry(
 #if !defined(PINKTRACE_FREEBSD)
-	PINK_UNUSED int argc, PINK_UNUSED VALUE *argv,
+	PINK_GCC_ATTR((unused)) int argc, PINK_GCC_ATTR((unused)) VALUE *argv,
 #else
 	int argc, VALUE *argv,
 #endif
-	PINK_UNUSED VALUE mod)
+	PINK_GCC_ATTR((unused)) VALUE mod)
 {
 #if defined(PINKTRACE_FREEBSD)
 	pid_t pid;
@@ -538,16 +538,16 @@ pinkrb_trace_syscall_entry(
  * Availability: FreeBSD
  */
 #if !defined(PINKTRACE_FREEBSD)
-PINK_NORETURN
+PINK_GCC_ATTR((noreturn))
 #endif
 static VALUE
 pinkrb_trace_syscall_exit(
 #if !defined(PINKTRACE_FREEBSD)
-	PINK_UNUSED int argc, PINK_UNUSED VALUE *argv,
+	PINK_GCC_ATTR((unused)) int argc, PINK_GCC_ATTR((unused)) VALUE *argv,
 #else
 	int argc, VALUE *argv,
 #endif
-	PINK_UNUSED VALUE mod)
+	PINK_GCC_ATTR((unused)) VALUE mod)
 {
 #if defined(PINKTRACE_FREEBSD)
 	pid_t pid;
@@ -588,16 +588,16 @@ pinkrb_trace_syscall_exit(
  * Availability: Linux
  */
 #if !defined(PINKTRACE_LINUX)
-PINK_NORETURN
+PINK_GCC_ATTR((noreturn))
 #endif
 static VALUE
 pinkrb_trace_sysemu(
 #if !defined(PINKTRACE_LINUX)
-	PINK_UNUSED int argc, PINK_UNUSED VALUE *argv,
+	PINK_GCC_ATTR((unused)) int argc, PINK_GCC_ATTR((unused)) VALUE *argv,
 #else
 	int argc, VALUE *argv,
 #endif
-	PINK_UNUSED VALUE mod)
+	PINK_GCC_ATTR((unused)) VALUE mod)
 {
 #if defined(PINKTRACE_LINUX)
 	pid_t pid;
@@ -638,16 +638,16 @@ pinkrb_trace_sysemu(
  * Availability: Linux
  */
 #if !defined(PINKTRACE_LINUX)
-PINK_NORETURN
+PINK_GCC_ATTR((noreturn))
 #endif
 static VALUE
 pinkrb_trace_sysemu_singlestep(
 #if !defined(PINKTRACE_LINUX)
-	PINK_UNUSED int argc, PINK_UNUSED VALUE *argv,
+	PINK_GCC_ATTR((unused)) int argc, PINK_GCC_ATTR((unused)) VALUE *argv,
 #else
 	int argc, VALUE *argv,
 #endif
-	PINK_UNUSED VALUE mod)
+	PINK_GCC_ATTR((unused)) VALUE mod)
 {
 #if defined(PINKTRACE_LINUX)
 	pid_t pid;
@@ -687,12 +687,12 @@ pinkrb_trace_sysemu_singlestep(
  * Availability: Linux
  */
 #if !defined(PINKTRACE_LINUX)
-PINK_NORETURN
+PINK_GCC_ATTR((noreturn))
 #endif
 static VALUE
-pinkrb_trace_geteventmsg(PINK_UNUSED VALUE mod,
+pinkrb_trace_geteventmsg(PINK_GCC_ATTR((unused)) VALUE mod,
 #if !defined(PINKTRACE_LINUX)
-	PINK_UNUSED
+	PINK_GCC_ATTR((unused))
 #endif
 	VALUE vpid)
 {
@@ -712,23 +712,23 @@ pinkrb_trace_geteventmsg(PINK_UNUSED VALUE mod,
 
 /*
  * Document-method: PinkTrace::Trace.setup
- * call-seq: PinkTrace::Trace.setup(pid, [options=PinkTrace::Trace::OPTION_SYSGOOD]) => nil
+ * call-seq: PinkTrace::Trace.setup(pid, [options=0]) => nil
  *
  * Sets the tracing options.
  *
  * Availability: Linux
  */
 #if !defined(PINKTRACE_LINUX)
-PINK_NORETURN
+PINK_GCC_ATTR((noreturn))
 #endif
 static VALUE
 pinkrb_trace_setup(
 #if !defined(PINKTRACE_LINUX)
-	PINK_UNUSED int argc, PINK_UNUSED VALUE *argv,
+	PINK_GCC_ATTR((unused)) int argc, PINK_GCC_ATTR((unused)) VALUE *argv,
 #else
 	int argc, VALUE *argv,
 #endif
-	PINK_UNUSED VALUE mod)
+	PINK_GCC_ATTR((unused)) VALUE mod)
 {
 #if defined(PINKTRACE_LINUX)
 	pid_t pid;
@@ -737,7 +737,7 @@ pinkrb_trace_setup(
 
 	switch (rb_scan_args(argc, argv, "11", &vpid, &vopts)) {
 	case 1:
-		opts = PINK_TRACE_OPTION_SYSGOOD;
+		opts = 0;
 		break;
 	case 2:
 		opts = NUM2INT(vopts);
@@ -767,7 +767,7 @@ pinkrb_trace_setup(
  * child to stop.
  */
 static VALUE
-pinkrb_trace_attach(PINK_UNUSED VALUE mod, VALUE vpid)
+pinkrb_trace_attach(PINK_GCC_ATTR((unused)) VALUE mod, VALUE vpid)
 {
 	pid_t pid;
 
@@ -789,7 +789,7 @@ pinkrb_trace_attach(PINK_UNUSED VALUE mod, VALUE vpid)
  * PinkTrace::Trace.cont.
  */
 static VALUE
-pinkrb_trace_detach(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
+pinkrb_trace_detach(int argc, VALUE *argv, PINK_GCC_ATTR((unused)) VALUE mod)
 {
 	pid_t pid;
 	long sig;
@@ -826,6 +826,10 @@ pinkrb_trace_detach(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
  *
  *   The traced child has received a SIGSTOP.
  *
+ * - PinkTrace::Event::EVENT_TRAP
+ *
+ *   The traced child has received a SIGTRAP.
+ *
  * - PinkTrace::Event::EVENT_SYSCALL
  *
  *   The traced child is entering or exiting a system call.
@@ -861,7 +865,6 @@ pinkrb_trace_detach(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
  * - PinkTrace::Event::EVENT_EXIT_SIGNAL
  *
  *   The traced child has been terminated with a signal.
- *
  */
 
 /*
@@ -869,22 +872,10 @@ pinkrb_trace_detach(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
  * call-seq: PinkTrace::Event.decide([status=$?.status]) => fixnum
  *
  * Returns the last event made by child.
- *
- * Availability: Linux
  */
-#if !defined(PINKTRACE_LINUX)
-PINK_NORETURN
-#endif
 static VALUE
-pinkrb_event_decide(
-#if !defined(PINKTRACE_LINUX)
-	PINK_UNUSED int argc, PINK_UNUSED VALUE *argv,
-#else
-	int argc, VALUE *argv,
-#endif
-	PINK_UNUSED VALUE mod)
+pinkrb_event_decide(int argc, VALUE *argv, PINK_GCC_ATTR((unused)) VALUE mod)
 {
-#if defined(PINKTRACE_LINUX)
 	unsigned int event;
 	int status;
 	VALUE vstatus, ls;
@@ -910,9 +901,6 @@ pinkrb_event_decide(
 
 	event = pink_event_decide(status);
 	return UINT2NUM(event);
-#else
-	rb_raise(rb_eNotImpError, "Not implemented");
-#endif /* defined(PINKTRACE_LINUX) */
 }
 
 /*
@@ -954,7 +942,7 @@ pinkrb_event_decide(
  * Returns the bitness of the traced child.
  */
 static VALUE
-pinkrb_bitness_get(PINK_UNUSED VALUE mod, VALUE vpid)
+pinkrb_bitness_get(PINK_GCC_ATTR((unused)) VALUE mod, VALUE vpid)
 {
 	pid_t pid;
 	int bit;
@@ -974,7 +962,7 @@ pinkrb_bitness_get(PINK_UNUSED VALUE mod, VALUE vpid)
  * Returns the name of the given bitness.
  */
 static VALUE
-pinkrb_bitness_name(PINK_UNUSED VALUE mod, VALUE vbit)
+pinkrb_bitness_name(PINK_GCC_ATTR((unused)) VALUE mod, VALUE vbit)
 {
 	pink_bitness_t bit;
 
@@ -989,7 +977,7 @@ pinkrb_bitness_name(PINK_UNUSED VALUE mod, VALUE vbit)
  * Returns the word size of the given bitness.
  */
 static VALUE
-pinkrb_bitness_wordsize(PINK_UNUSED VALUE mod, VALUE vbit)
+pinkrb_bitness_wordsize(PINK_GCC_ATTR((unused)) VALUE mod, VALUE vbit)
 {
 	unsigned short wordsize;
 	unsigned bit;
@@ -1029,7 +1017,7 @@ pinkrb_bitness_wordsize(PINK_UNUSED VALUE mod, VALUE vbit)
  * or undefined.
  */
 static VALUE
-pinkrb_name_syscall(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
+pinkrb_name_syscall(int argc, VALUE *argv, PINK_GCC_ATTR((unused)) VALUE mod)
 {
 	unsigned bit;
 	long scno;
@@ -1064,7 +1052,7 @@ pinkrb_name_syscall(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
  * or undefined.
  */
 static VALUE
-pinkrb_name_lookup(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
+pinkrb_name_lookup(int argc, VALUE *argv, PINK_GCC_ATTR((unused)) VALUE mod)
 {
 	unsigned bit;
 	const char *name;
@@ -1098,7 +1086,7 @@ pinkrb_name_lookup(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
  * Returns the last system call number called by the traced child.
  */
 static VALUE
-pinkrb_util_get_syscall(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
+pinkrb_util_get_syscall(int argc, VALUE *argv, PINK_GCC_ATTR((unused)) VALUE mod)
 {
 	pid_t pid;
 	unsigned bit;
@@ -1131,7 +1119,7 @@ pinkrb_util_get_syscall(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
  * Sets the system call number for the traced child.
  */
 static VALUE
-pinkrb_util_set_syscall(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
+pinkrb_util_set_syscall(int argc, VALUE *argv, PINK_GCC_ATTR((unused)) VALUE mod)
 {
 	pid_t pid;
 	unsigned bit;
@@ -1165,7 +1153,7 @@ pinkrb_util_set_syscall(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
  * Returns the return value of the last system call called by the traced child.
  */
 static VALUE
-pinkrb_util_get_return(PINK_UNUSED VALUE mod, VALUE vpid)
+pinkrb_util_get_return(PINK_GCC_ATTR((unused)) VALUE mod, VALUE vpid)
 {
 	pid_t pid;
 	long ret;
@@ -1184,7 +1172,7 @@ pinkrb_util_get_return(PINK_UNUSED VALUE mod, VALUE vpid)
  * Set the return value of the system call for the traced child.
  */
 static VALUE
-pinkrb_util_set_return(PINK_UNUSED VALUE mod, VALUE vpid, VALUE vret)
+pinkrb_util_set_return(PINK_GCC_ATTR((unused)) VALUE mod, VALUE vpid, VALUE vret)
 {
 	pid_t pid;
 	long ret;
@@ -1211,7 +1199,7 @@ pinkrb_util_set_return(PINK_UNUSED VALUE mod, VALUE vpid, VALUE vret)
  * or undefined.
  */
 static VALUE
-pinkrb_util_get_arg(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
+pinkrb_util_get_arg(int argc, VALUE *argv, PINK_GCC_ATTR((unused)) VALUE mod)
 {
 	pid_t pid;
 	unsigned bit, ind;
@@ -1252,7 +1240,7 @@ pinkrb_util_get_arg(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
  * or undefined.
  */
 static VALUE
-pinkrb_util_set_arg(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
+pinkrb_util_set_arg(int argc, VALUE *argv, PINK_GCC_ATTR((unused)) VALUE mod)
 {
 	pid_t pid;
 	unsigned bit, ind;
@@ -1302,7 +1290,7 @@ pinkrb_util_set_arg(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
  * or undefined.
  */
 static VALUE
-pinkrb_decode_string(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
+pinkrb_decode_string(int argc, VALUE *argv, PINK_GCC_ATTR((unused)) VALUE mod)
 {
 	pid_t pid;
 	unsigned bit, ind;
@@ -1368,16 +1356,16 @@ pinkrb_decode_string(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
  * Availability: Linux
  */
 #if !defined(PINKTRACE_LINUX)
-PINK_NORETURN
+PINK_GCC_ATTR((noreturn))
 #endif
 static VALUE
 pinkrb_encode_string_safe(
 #if !defined(PINKTRACE_LINUX)
-	PINK_UNUSED int argc, PINK_UNUSED VALUE *argv,
+	PINK_GCC_ATTR((unused)) int argc, PINK_GCC_ATTR((unused)) VALUE *argv,
 #else
 	int argc, VALUE *argv,
 #endif
-	PINK_UNUSED VALUE mod)
+	PINK_GCC_ATTR((unused)) VALUE mod)
 {
 #if defined(PINKTRACE_LINUX)
 	pid_t pid;
@@ -1432,7 +1420,7 @@ pinkrb_encode_string_safe(
  * or undefined.
  */
 static VALUE
-pinkrb_encode_string(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
+pinkrb_encode_string(int argc, VALUE *argv, PINK_GCC_ATTR((unused)) VALUE mod)
 {
 	pid_t pid;
 	unsigned bit, ind;
@@ -1490,7 +1478,7 @@ pinkrb_encode_string(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
  * or undefined.
  */
 static VALUE
-pinkrb_decode_strarray(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
+pinkrb_decode_strarray(int argc, VALUE *argv, PINK_GCC_ATTR((unused)) VALUE mod)
 {
 	bool nil;
 	pid_t pid;
@@ -1568,16 +1556,16 @@ pinkrb_decode_strarray(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
  * Availability: Linux
  */
 #if !defined(PINKTRACE_LINUX)
-PINK_NORETURN
+PINK_GCC_ATTR((noreturn))
 #endif
 static VALUE
-pinkrb_has_socketcall(PINK_UNUSED VALUE mod,
+pinkrb_has_socketcall(PINK_GCC_ATTR((unused)) VALUE mod,
 #if !defined(PINKTRACE_LINUX)
-		PINK_UNUSED
+		PINK_GCC_ATTR((unused))
 #endif
 		int argc,
 #if !defined(PINKTRACE_LINUX)
-		PINK_UNUSED
+		PINK_GCC_ATTR((unused))
 #endif
 		VALUE *argv)
 {
@@ -1612,12 +1600,12 @@ pinkrb_has_socketcall(PINK_UNUSED VALUE mod,
  * Availability: Linux
  */
 #if !defined(PINKTRACE_LINUX)
-PINK_NORETURN
+PINK_GCC_ATTR((noreturn))
 #endif
 static VALUE
-pinkrb_name_socket_subcall(PINK_UNUSED VALUE mod,
+pinkrb_name_socket_subcall(PINK_GCC_ATTR((unused)) VALUE mod,
 #if !defined(PINKTRACE_LINUX)
-	PINK_UNUSED
+	PINK_GCC_ATTR((unused))
 #endif
 	VALUE vsubcall)
 {
@@ -1648,16 +1636,16 @@ pinkrb_name_socket_subcall(PINK_UNUSED VALUE mod,
  * Availability: Linux
  */
 #if !defined(PINKTRACE_LINUX)
-PINK_NORETURN
+PINK_GCC_ATTR((noreturn))
 #endif
 static VALUE
 pinkrb_decode_socket_call(
 #if !defined(PINKTRACE_LINUX)
-	PINK_UNUSED int argc, PINK_UNUSED VALUE *argv,
+	PINK_GCC_ATTR((unused)) int argc, PINK_GCC_ATTR((unused)) VALUE *argv,
 #else
 	int argc, VALUE *argv,
 #endif
-	PINK_UNUSED VALUE mod)
+	PINK_GCC_ATTR((unused)) VALUE mod)
 {
 #if defined(PINKTRACE_LINUX)
 	pid_t pid;
@@ -1705,16 +1693,16 @@ pinkrb_decode_socket_call(
  * Availability: Linux
  */
 #if !defined(PINKTRACE_LINUX)
-PINK_NORETURN
+PINK_GCC_ATTR((noreturn))
 #endif
 static VALUE
 pinkrb_decode_socket_fd(
 #if !defined(PINKTRACE_LINUX)
-	PINK_UNUSED int argc, PINK_UNUSED VALUE *argv,
+	PINK_GCC_ATTR((unused)) int argc, PINK_GCC_ATTR((unused)) VALUE *argv,
 #else
 	int argc, VALUE *argv,
 #endif
-	PINK_UNUSED VALUE mod)
+	PINK_GCC_ATTR((unused)) VALUE mod)
 {
 #if defined(PINKTRACE_LINUX)
 	pid_t pid;
@@ -1773,7 +1761,7 @@ pinkrb_decode_socket_fd(
  * or undefined.
  */
 static VALUE
-pinkrb_decode_socket_address(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
+pinkrb_decode_socket_address(int argc, VALUE *argv, PINK_GCC_ATTR((unused)) VALUE mod)
 {
 	pid_t pid;
 	unsigned bit, ind;
@@ -1819,7 +1807,7 @@ pinkrb_decode_socket_address(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
  * or undefined.
  */
 static VALUE
-pinkrb_decode_socket_address_fd(int argc, VALUE *argv, PINK_UNUSED VALUE mod)
+pinkrb_decode_socket_address_fd(int argc, VALUE *argv, PINK_GCC_ATTR((unused)) VALUE mod)
 {
 	pid_t pid;
 	unsigned bit, ind;
@@ -1920,12 +1908,12 @@ pinkrb_Address_is_inet(VALUE self)
  * Returns true if the address is of family +AF_INET6+.
  */
 #if !PINKTRACE_HAVE_IPV6
-PINK_NORETURN
+PINK_GCC_ATTR((noreturn))
 #endif /* !PINKTRACE_HAVE_IPV6 */
 static VALUE
 pinkrb_Address_is_inet6(
 #if !PINKTRACE_HAVE_IPV6
-	PINK_UNUSED
+	PINK_GCC_ATTR((unused))
 #endif /* !PINKTRACE_HAVE_IPV6 */
 	VALUE self)
 {
@@ -1946,12 +1934,12 @@ pinkrb_Address_is_inet6(
  * Returns true if the address is of family +AF_NETLINK+.
  */
 #if !PINKTRACE_HAVE_NETLINK
-PINK_NORETURN
+PINK_GCC_ATTR((noreturn))
 #endif /* !PINKTRACE_HAVE_NETLINK */
 static VALUE
 pinkrb_Address_is_netlink(
 #if !PINKTRACE_HAVE_NETLINK
-	PINK_UNUSED
+	PINK_GCC_ATTR((unused))
 #endif /* !PINKTRACE_HAVE_NETLINK */
 	VALUE self)
 {
@@ -2013,10 +2001,10 @@ pinkrb_Address_port(VALUE self)
 	Data_Get_Struct(self, pink_socket_address_t, addr);
 	switch (addr->family) {
 	case AF_INET:
-		return FIX2INT(ntohs(addr->u.sa_in.sin_port));
+		return INT2FIX(ntohs(addr->u.sa_in.sin_port));
 #if PINKTRACE_HAVE_IPV6
 	case AF_INET6:
-		return FIX2INT(ntohs(addr->u.sa6.sin6_port));
+		return INT2FIX(ntohs(addr->u.sa6.sin6_port));
 #endif /* PINKTRACE_HAVE_IPV6 */
 	default:
 		rb_raise(rb_eTypeError, "Invalid family");
@@ -2053,12 +2041,12 @@ pinkrb_Address_ip(VALUE self)
  * Returns the IPV6 address of an Inet6 socket address as string.
  */
 #if !PINKTRACE_HAVE_IPV6
-PINK_NORETURN
+PINK_GCC_ATTR((noreturn))
 #endif /* !PINKTRACE_HAVE_IPV6 */
 static VALUE
 pinkrb_Address_ipv6(
 #if !PINKTRACE_HAVE_IPV6
-	PINK_UNUSED
+	PINK_GCC_ATTR((unused))
 #endif /* !PINKTRACE_HAVE_IPV6 */
 	VALUE self)
 {
@@ -2087,12 +2075,12 @@ pinkrb_Address_ipv6(
  * Returns the process ID of the netlink socket address
  */
 #if !PINKTRACE_HAVE_NETLINK
-PINK_NORETURN
+PINK_GCC_ATTR((noreturn))
 #endif /* !PINKTRACE_HAVE_NETLINK */
 static VALUE
 pinkrb_Address_pid(
 #if !PINKTRACE_HAVE_NETLINK
-	PINK_UNUSED
+	PINK_GCC_ATTR((unused))
 #endif /* !PINKTRACE_HAVE_NETLINK */
 	VALUE self)
 {
@@ -2113,12 +2101,12 @@ pinkrb_Address_pid(
  * Returns the mcast groups mask of the netlink socket address
  */
 #if !PINKTRACE_HAVE_NETLINK
-PINK_NORETURN
+PINK_GCC_ATTR((noreturn))
 #endif /* !PINKTRACE_HAVE_NETLINK */
 static VALUE
 pinkrb_Address_groups(
 #if !PINKTRACE_HAVE_NETLINK
-	PINK_UNUSED
+	PINK_GCC_ATTR((unused))
 #endif /* !PINKTRACE_HAVE_NETLINK */
 	VALUE self)
 {
@@ -2191,8 +2179,8 @@ Init_PinkTrace(void)
 
 	/* event.h */
 	event_mod = rb_define_module_under(mod, "Event");
-#if defined(PINKTRACE_LINUX)
 	rb_define_const(event_mod, "EVENT_STOP", INT2FIX(PINK_EVENT_STOP));
+	rb_define_const(event_mod, "EVENT_TRAP", INT2FIX(PINK_EVENT_TRAP));
 	rb_define_const(event_mod, "EVENT_SYSCALL", INT2FIX(PINK_EVENT_SYSCALL));
 	rb_define_const(event_mod, "EVENT_FORK", INT2FIX(PINK_EVENT_FORK));
 	rb_define_const(event_mod, "EVENT_VFORK", INT2FIX(PINK_EVENT_VFORK));
@@ -2204,7 +2192,6 @@ Init_PinkTrace(void)
 	rb_define_const(event_mod, "EVENT_EXIT_GENUINE", INT2FIX(PINK_EVENT_EXIT_GENUINE));
 	rb_define_const(event_mod, "EVENT_EXIT_SIGNAL", INT2FIX(PINK_EVENT_EXIT_SIGNAL));
 	rb_define_const(event_mod, "EVENT_UNKNOWN", INT2FIX(PINK_EVENT_UNKNOWN));
-#endif /* defined(PINKTRACE_LINUX) */
 	rb_define_module_function(event_mod, "decide", pinkrb_event_decide, -1);
 
 	/* bitness.h */
