@@ -1,7 +1,7 @@
 /* vim: set cino= fo=croql sw=8 ts=8 sts=0 noet cin fdm=syntax : */
 
 /*
- * Copyright (c) 2010 Ali Polatel <alip@exherbo.org>
+ * Copyright (c) 2010, 2011 Ali Polatel <alip@exherbo.org>
  * Based in part upon strace which is:
  *   Copyright (c) 1991, 1992 Paul Kranenburg <pk@cs.few.eur.nl>
  *   Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
@@ -52,9 +52,9 @@ pink_util_arg_setup_ia64(pid_t pid, int narg, unsigned long *state)
 	unsigned long *out0, cfm, sof, sol;
 	long rbs_end;
 
-	if (PINK_UNLIKELY(!pink_util_peek(pid, PT_AR_BSP, &rbs_end)))
+	if (PINK_GCC_UNLIKELY(!pink_util_peek(pid, PT_AR_BSP, &rbs_end)))
 		return false;
-	if (PINK_UNLIKELY(!pink_util_peek(pid, PT_CFM, (long *)&cfm)))
+	if (PINK_GCC_UNLIKELY(!pink_util_peek(pid, PT_CFM, (long *)&cfm)))
 		return false;
 
 	sof = (cfm >> 0) & 0x7f;
@@ -66,26 +66,26 @@ pink_util_arg_setup_ia64(pid_t pid, int narg, unsigned long *state)
 }
 
 pink_bitness_t
-pink_bitness_get(PINK_UNUSED pid_t pid)
+pink_bitness_get(PINK_GCC_ATTR((unused)) pid_t pid)
 {
 	return PINK_BITNESS_64;
 }
 
 inline
 unsigned short
-pink_bitness_wordsize(PINK_UNUSED pink_bitness_t bitness)
+pink_bitness_wordsize(PINK_GCC_ATTR((unused)) pink_bitness_t bitness)
 {
 	return 8;
 }
 
 bool
-pink_util_get_syscall(pid_t pid, PINK_UNUSED pink_bitness_t bitness, long *res)
+pink_util_get_syscall(pid_t pid, PINK_GCC_ATTR((unused)) pink_bitness_t bitness, long *res)
 {
 	return pink_util_peek(pid, ORIG_ACCUM, res);
 }
 
 bool
-pink_util_set_syscall(pid_t pid, PINK_UNUSED pink_bitness_t bitness, long scno)
+pink_util_set_syscall(pid_t pid, PINK_GCC_ATTR((unused)) pink_bitness_t bitness, long scno)
 {
 	return pink_util_poke(pid, ORIG_ACCUM, scno);
 }
@@ -97,7 +97,7 @@ pink_util_get_return(pid_t pid, long *res)
 
 	assert(res != NULL);
 
-	if (PINK_UNLIKELY(!pink_util_peek(pid, PT_R8, &r8)
+	if (PINK_GCC_UNLIKELY(!pink_util_peek(pid, PT_R8, &r8)
 				|| !pink_util_peek(pid, PT_R10, &r10)))
 		return false;
 
@@ -117,7 +117,7 @@ pink_util_set_return(pid_t pid, long ret)
 }
 
 bool
-pink_util_get_arg(pid_t pid, PINK_UNUSED pink_bitness_t bitness, unsigned ind, long *res)
+pink_util_get_arg(pid_t pid, PINK_GCC_ATTR((unused)) pink_bitness_t bitness, unsigned ind, long *res)
 {
 	unsigned long state;
 
@@ -128,7 +128,7 @@ pink_util_get_arg(pid_t pid, PINK_UNUSED pink_bitness_t bitness, unsigned ind, l
 }
 
 bool
-pink_util_set_arg(pid_t pid, PINK_UNUSED pink_bitness_t bitness, unsigned ind, long arg)
+pink_util_set_arg(pid_t pid, PINK_GCC_ATTR((unused)) pink_bitness_t bitness, unsigned ind, long arg)
 {
 	unsigned long state;
 
@@ -166,7 +166,7 @@ pink_decode_string_persistent(pid_t pid, pink_bitness_t bitness, unsigned ind)
 
 	assert(ind < PINK_MAX_INDEX);
 
-	if (PINK_UNLIKELY(!pink_util_get_arg(pid, bitness, ind, &addr)))
+	if (PINK_GCC_UNLIKELY(!pink_util_get_arg(pid, bitness, ind, &addr)))
 		return NULL;
 
 	return pink_util_movestr_persistent(pid, addr);
@@ -193,7 +193,7 @@ pink_encode_simple_safe(pid_t pid, pink_bitness_t bitness, unsigned ind, const v
 }
 
 bool
-pink_has_socketcall(PINK_UNUSED pink_bitness_t bitness)
+pink_has_socketcall(PINK_GCC_ATTR((unused)) pink_bitness_t bitness)
 {
 	return false;
 }
@@ -225,11 +225,11 @@ pink_decode_socket_address(pid_t pid, pink_bitness_t bitness, unsigned ind, long
 	assert(paddr != NULL);
 
 	/* No decoding needed */
-	if (PINK_UNLIKELY(fd && !pink_util_get_arg(pid, bitness, 0, fd)))
+	if (PINK_GCC_UNLIKELY(fd && !pink_util_get_arg(pid, bitness, 0, fd)))
 		return false;
-	if (PINK_UNLIKELY(!pink_util_get_arg(pid, bitness, ind, &addr)))
+	if (PINK_GCC_UNLIKELY(!pink_util_get_arg(pid, bitness, ind, &addr)))
 		return false;
-	if (PINK_UNLIKELY(!pink_util_get_arg(pid, bitness, ind + 1, &addrlen)))
+	if (PINK_GCC_UNLIKELY(!pink_util_get_arg(pid, bitness, ind + 1, &addrlen)))
 		return false;
 
 	return pink_internal_decode_socket_address(pid, addr, addrlen, paddr);
